{{/* vim: set filetype=mustache: */}}
{{/*
Expand the name of the chart.
*/}}
{{- define "collector.name" -}}
{{- default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name.
*/}}
{{- define "collector.fullname" -}}
{{- if .Values.fullnameOverride -}}
{{- .Values.fullnameOverride | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- $name := default .Chart.Name .Values.nameOverride -}}
{{- if contains $name .Release.Name -}}
{{- .Release.Name | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- printf "%s-%s" .Release.Name $name | trunc 63 | trimSuffix "-" -}}
{{- end -}}
{{- end -}}
{{- end -}}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "collector.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Compute if the collector is enabled.
*/}}
{{- define "collector.collectorEnabled" -}}
{{- $_ := set . "collectorEnabled" (or
  (eq (.Values.collector.enabled | toString) "true")
  (and (eq (.Values.collector.enabled | toString) "-") (eq (.Values.global.enabled | toString) "true"))) -}}
{{- end -}}

{{/*
Create the name of the service account to use for creating or deleting the collector
*/}}
{{- define "collector.serviceAccount" -}}
{{- if .Values.collector.serviceAccount.create -}}
    {{ default (include "collector.fullname" .) .Values.collector.serviceAccount.name }}
{{- else -}}
    {{ default "default" .Values.collector.serviceAccount.name }}
{{- end -}}
{{- end -}}

{{/*
Create the name for the credentials secret.
*/}}
{{- define "collector.secretName" -}}
{{- if .Values.credentials.existingSecret -}}
  {{- .Values.credentials.existingSecret -}}
{{- else -}}
  {{ default (include "collector.fullname" .) .Values.credentials.name }}
{{- end -}}
{{- end -}}

{{/*
imagePullSecrets generates pull secrets from either string or map values.
A map value must be indexable by the key 'name'.
*/}}
{{- define "imagePullSecrets" -}}
{{- with .Values.global.imagePullSecrets -}}
imagePullSecrets:
{{- range . -}}
{{- if typeIs "string" . }}
  - name: {{ . }}
{{- else if index . "name" }}
  - name: {{ .name }}
{{- end }}
{{- end -}}
{{- end -}}
{{- end -}}

{{/*
Sets the collector deployment update strategy
*/}}
{{- define "collector.strategy" -}}
  {{- if .Values.collector.strategy }}
  strategy:
  {{- $tp := typeOf .Values.collector.strategy }}
  {{- if eq $tp "string" }}
    {{ tpl .Values.collector.strategy . | nindent 4 | trim }}
  {{- else }}
    {{- toYaml .Values.collector.strategy | nindent 4 }}
  {{- end }}
  {{- end }}
{{- end -}}

{{/*
Sets extra pod annotations
*/}}
{{- define "collector.annotations" -}}
  {{- if .Values.collector.annotations }}
      annotations:
        {{- $tp := typeOf .Values.collector.annotations }}
        {{- if eq $tp "string" }}
          {{- tpl .Values.collector.annotations . | nindent 4 }}
        {{- else }}
          {{- toYaml .Values.collector.annotations | nindent 4 }}
        {{- end }}
  {{- end }}
{{- end -}}

{{/*
Sets the affinity for pod placement
*/}}
{{- define "collector.affinity" -}}
  {{- if .Values.collector.affinity }}
      affinity:
        {{ $tp := typeOf .Values.collector.affinity }}
        {{- if eq $tp "string" }}
          {{- tpl .Values.collector.affinity . | nindent 8 | trim }}
        {{- else }}
          {{- toYaml .Values.collector.affinity | nindent 8 }}
        {{- end }}
  {{ end }}
{{- end -}}

{{/*
Sets the topologySpreadConstraints for pod placement
*/}}
{{- define "collector.topologySpreadConstraints" -}}
  {{- if .Values.collector.topologySpreadConstraints }}
      topologySpreadConstraints:
        {{ $tp := typeOf .Values.collector.topologySpreadConstraints }}
        {{- if eq $tp "string" }}
          {{- tpl .Values.collector.topologySpreadConstraints . | nindent 8 | trim }}
        {{- else }}
          {{- toYaml .Values.collector.topologySpreadConstraints | nindent 8 }}
        {{- end }}
  {{ end }}
{{- end -}}

{{/*
Sets the toleration for pod placement
*/}}
{{- define "collector.tolerations" -}}
  {{- if .Values.collector.tolerations }}
      tolerations:
      {{- $tp := typeOf .Values.collector.tolerations }}
      {{- if eq $tp "string" }}
        {{ tpl .Values.collector.tolerations . | nindent 8 | trim }}
      {{- else }}
        {{- toYaml .Values.collector.tolerations | nindent 8 }}
      {{- end }}
  {{- end }}
{{- end -}}

{{/*
Sets the node selector for pod placement
*/}}
{{- define "collector.nodeselector" -}}
  {{- if .Values.collector.nodeSelector }}
      nodeSelector:
      {{- $tp := typeOf .Values.collector.nodeSelector }}
      {{- if eq $tp "string" }}
        {{ tpl .Values.collector.nodeSelector . | nindent 8 | trim }}
      {{- else }}
        {{- toYaml .Values.collector.nodeSelector | nindent 8 }}
      {{- end }}
  {{- end }}
{{- end -}}

{{/*
securityContext for the pod level.
*/}}
{{- define "collector.securityContext.pod" -}}
  {{- if .Values.collector.securityContext.pod }}
      securityContext:
        {{- $tp := typeOf .Values.collector.securityContext.pod }}
        {{- if eq $tp "string" }}
          {{- tpl .Values.collector.securityContext.pod . | nindent 8 }}
        {{- else }}
          {{- toYaml .Values.collector.securityContext.pod | nindent 8 }}
        {{- end }}
  {{- else if not .Values.global.openshift }}
      securityContext:
        runAsNonRoot: true
        runAsGroup: {{ .Values.collector.gid | default 1000 }}
        runAsUser: {{ .Values.collector.uid | default 100 }}
        fsGroup: {{ .Values.collector.gid | default 1000 }}
        seccompProfile:
          type: RuntimeDefault
  {{- end }}
{{- end -}}

{{/*
Sets the container resources if the user has set any.
*/}}
{{- define "collector.resources" -}}
  {{- if .Values.collector.resources -}}
          resources:
{{ toYaml .Values.collector.resources | indent 12}}
  {{ end }}
{{- end -}}

{{/*
securityContext for the container level.
*/}}
{{- define "collector.securityContext.container" -}}
  {{- if .Values.collector.securityContext.container}}
          securityContext:
            {{- $tp := typeOf .Values.collector.securityContext.container }}
            {{- if eq $tp "string" }}
              {{- tpl .Values.collector.securityContext.container . | nindent 12 }}
            {{- else }}
              {{- toYaml .Values.collector.securityContext.container | nindent 12 }}
            {{- end }}
  {{- else if not .Values.global.openshift }}
          securityContext:
            allowPrivilegeEscalation: false
            capabilities:
              drop:
                - ALL
  {{- end }}
{{- end -}}

{{/*
Inject extra environment vars in the format key:value, if populated
*/}}
{{- define "collector.extraEnvironmentVars" -}}
{{- if .extraEnvironmentVars -}}
{{- range $key, $value := .extraEnvironmentVars }}
- name: {{ printf "%s" $key | replace "." "_" | upper | quote }}
  value: {{ $value | quote }}
{{- end }}
{{- end -}}
{{- end -}}

{{/*
Inject extra environment populated by secrets, if populated
*/}}
{{- define "collector.extraSecretEnvironmentVars" -}}
{{- if .extraSecretEnvironmentVars -}}
{{- range .extraSecretEnvironmentVars }}
- name: {{ .envName }}
  valueFrom:
   secretKeyRef:
     name: {{ .secretName }}
     key: {{ .secretKey }}
{{- end -}}
{{- end -}}
{{- end -}}

{{/*
Set's which additional volumes should be mounted to the container.
*/}}
{{- define "collector.mounts" -}}
  {{- if .Values.collector.volumeMounts }}
    {{- toYaml .Values.collector.volumeMounts | nindent 12}}
  {{- end }}
{{- end -}}

{{/*
Iterates over any extra volumes the user may have specified (such as a secret
with TLS).
*/}}
{{- define "collector.volumes" -}}
  {{- range .Values.collector.extraVolumes }}
        - name: userconfig-{{ .name }}
          {{ .type }}:
          {{- if (eq .type "configMap") }}
            name: {{ .name }}
          {{- else if (eq .type "secret") }}
            secretName: {{ .name }}
          {{- end }}
            defaultMode: {{ .defaultMode | default 420 }}
  {{- end }}
  {{- if .Values.collector.volumes }}
    {{- toYaml .Values.collector.volumes | nindent 8}}
  {{- end }}
{{- end -}}

{{/*
Validate the required parameters for the k8s collector deployment
*/}}
{{ required "A valid collectorId is required!" .Values.config.collectorId }}
{{ required "A valid clusterName is required!" .Values.config.clusterName }}
{{ required "A valid clusterRegion is required!" .Values.config.clusterRegion }}
{{ required "A valid clusterCloudAccountId is required!"  .Values.config.clusterCloudAccountId }}
{{ required "A valid CSP Org ID is required!" .Values.csp.orgId }}